@@ -1,14 +1,14 @@
 # nocov start
 
 #' @import base64enc
-livy_invoke_serialize <- function(sc, static, object, method, ...)
-{
+livy_invoke_serialize <- function(sc, static, object, method, ...) {
   if (is.null(sc)) {
     stop("The connection is no longer valid.")
   }
 
-  if (inherits(object, "livy_jobj"))
+  if (inherits(object, "livy_jobj")) {
     object <- object$id
+  }
 
   rc <- rawConnection(raw(), "r+")
   writeString(rc, object)
@@ -31,8 +31,9 @@ livy_invoke_deserialize <- function(sc, base64) {
   rc <- rawConnection(rv, "r+")
 
   returnStatus <- readInt(rc)
-  if (length(returnStatus) == 0)
+  if (length(returnStatus) == 0) {
     stop("No status is returned. Livy backend might have failed.")
+  }
   if (returnStatus != 0) {
     msg <- readString(rc)
     withr::with_options(list(
