@@ -62,8 +62,7 @@ spark_dependencies_from_extensions <- function(spark_version, scala_version, ext
         scala_version <- "2.11"
       } else {
         scala_version <- "2.12"
-      }
-    )
+      })
   )
   jars <- character()
   packages <- character()
@@ -161,8 +160,7 @@ sparklyr_jar_path <- function(spark_version, scala_version = NULL) {
       "2.11"
     } else {
       "2.12"
-    }
-  )
+    })
   spark_major_minor <- spark_version[1, 1:2]
 
   exact_jar <- sprintf("sparklyr-%s-%s.jar", spark_major_minor, scala_version)
@@ -175,7 +173,7 @@ sparklyr_jar_path <- function(spark_version, scala_version = NULL) {
     system.file(file.path("java", exact_jar), package = "sparklyr")
   } else if (spark_version > "1.6") {
     # Spark is backwards compatible so we can use a new version with the latest jar
-    all_versions <- sort(gsub("^sparklyr-|-[0-9]+\\.[0-9]+\\.jar$", "", all_jars), decreasing = T)
+    all_versions <- sort(gsub("^sparklyr-|-[0-9]+\\.[0-9]+\\.jar$", "", all_jars), decreasing = TRUE)
 
     # Support preview versions and master builds
     all_versions <- all_versions[all_versions != "master"]
@@ -185,7 +183,7 @@ sparklyr_jar_path <- function(spark_version, scala_version = NULL) {
 
     dir(system.file("java", package = "sparklyr"),
       pattern = paste0("sparklyr-", prev_versions[1]),
-      full.names = T
+      full.names = TRUE
     )
   } else {
     ""
